@@ -1499,14 +1499,12 @@ void PAS__STD_init_a_file(V F_fd, V F_pfspc){
     break;
     case 4:((UL *)Rv1)[14]=((UL *)Rv1)[14]|512;
     break;
-    case 5:((UL *)Rv1)[14]=((UL *)Rv1)[14]|2048;
+    case 5:((UL *)Rv1)[14]=((UL *)Rv1)[14]|2304;
     break;
-    case 6:((UL *)Rv1)[14]=((UL *)Rv1)[14]|6144;
+    case 6:((UL *)Rv1)[14]=((UL *)Rv1)[14]|6400;
     break;
     default:break;
   }
-  if (16&((UL *)Rv1)[14]&&(((UL *)Rv1)[14]&6144)!=0) ((UL *)Rv1)[14]=((UL *)Rv1)
-  [14]|256;
   if ((6144&((UL *)Rv1)[14])==0) {
     if (isatty(((SL *)Rv1)[7])!=0) {
       ((UL *)Rv1)[14]=((UL *)Rv1)[14]|1280;
@@ -1532,7 +1530,7 @@ void PAS__STD_init_a_file(V F_fd, V F_pfspc){
   ((SL *)Rv1)[13]=0;
   ((SL *)Rv1)[12]=0;
   ((SL *)Rv1)[11]=0;
-  if (!Rv0&&1&((UL *)Rv1)[14]) {
+  if (!(256&((UL *)Rv1)[14])&&1&((UL *)Rv1)[14]) {
     if (4&((UL *)Rv1)[14]) P_buffer_map(F_fd,0);
     else {
       if (8192&((UL *)Rv1)[14]) PAS__exe_proc(((V *)Rv1)[5],F_fd);
@@ -1852,24 +1850,28 @@ V PAS__FILE_SPC(V Ret, V F_fp){
 }
 
 
-/* Procedure/Function : " get_tty_name "  */
-void PAS__STD_PRC_00000001(SL F_lun, V F_sn){
+/* Procedure/Function : " check_descr "  */
+void PAS__STD_PRC_00000001(SL F_lun, UL F_fmd, V F_sn){
   /* Local variable stored in C variable */
-  V Rv0;
-  SL Rv1;
-  C Rv2;
+  SL Rv0;
+  V Rv1;
+  SL Rv2;
+  C Rv3;
 
   /* Code of procedure/function */
-  Rv0=_Ttyname(F_lun);
-  Rv1=0;
-  if (Rv0!=NULL) while (1){
-    Rv2=((C *)Rv0)[Rv1];
-    if (Rv2==0)  break;
-    Rv1=Rv1+1;
-    ((C *)F_sn)[Rv1+1]=Rv2;
-    if (Rv1>=((UB *)F_sn)[0])  break;
+  Rv0=PAS__STD_get_kind_of_file(F_lun);
+  Rv1=_Ttyname(F_lun);
+  if (Rv1!=NULL) {
+    Rv2=0;
+    while (1){
+      Rv3=((C *)Rv1)[Rv2];
+      if (Rv3==0)  break;
+      Rv2=Rv2+1;
+      ((C *)F_sn)[Rv2+1]=Rv3;
+      if (Rv2>=((UB *)F_sn)[0])  break;
+    }
+    ((UB *)F_sn)[1]=Rv2;
   }
-  ((UB *)F_sn)[1]=Rv1;
 }
 
 
@@ -1899,22 +1901,22 @@ void PAS__INIT(SL F_parc, V F_parv, V F_penv){
   Ri.sl[26]=1;
   Ri.sl[27]=256;
   Ri.ul[32]=67109009;
-  if (isatty(Ri.sl[25])!=0) PAS__STD_PRC_00000001(Ri.sl[25],Ra.s);
-  else PAS__STR_TO_STR(Ra.s,Rd.s+76);
+  PAS__STR_TO_STR(Ra.s,Rd.s+76);
+  PAS__STD_PRC_00000001(Ri.sl[25],O_RDONLY, Ra.s);
   PAS__STD_init_a_file(Ri.s+72,Ra.s);
   Ri.sl[40]=1;
   Ri.sl[41]=1;
   Ri.sl[42]=256;
   Ri.ul[47]=146;
-  if (isatty(Ri.sl[40])!=0) PAS__STD_PRC_00000001(Ri.sl[40],Ra.s);
-  else PAS__STR_TO_STR(Ra.s,Rd.s+87);
+  PAS__STR_TO_STR(Ra.s,Rd.s+87);
+  PAS__STD_PRC_00000001(Ri.sl[40],O_WRONLY, Ra.s);
   PAS__STD_init_a_file(Ri.s+132,Ra.s);
   Ri.sl[55]=2;
   Ri.sl[56]=1;
   Ri.sl[57]=256;
   Ri.ul[62]=146;
-  if (isatty(Ri.sl[55])!=0) PAS__STD_PRC_00000001(Ri.sl[55],Ra.s);
-  else PAS__STR_TO_STR(Ra.s,Rd.s+99);
+  PAS__STR_TO_STR(Ra.s,Rd.s+99);
+  PAS__STD_PRC_00000001(Ri.sl[55],O_WRONLY, Ra.s);
   PAS__STD_init_a_file(Ri.s+192,Ra.s);
   Ri.sl[9]=-1;
   Ri.sl[10]=1;
